eprllib.Env.MultiAgent.EnergyPlusEnvironment — eprllib: use EnergyPlus as an environment for DRL control

Skip to main content
`Ctrl`+`K`

# eprllib.Env.MultiAgent.EnergyPlusEnvironment

# ENERGYPLUS RLLIB ENVIRONMENT

This script define the environment of EnergyPlus implemented in RLlib. To works need to define the EnergyPlus Runner.

Classes

`EnergyPlusEnv_v0`(env_config) | The EnergyPlusEnv_v0 class represents a multi-agent environment for reinforcement learning tasks related to building energy simulation using EnergyPlus software.